pub struct ReflectionWalkProposal {
pub lower_bound: f64,
pub upper_bound: f64,
}Expand description
Reflection-based proposal for bounded continuous distributions (symmetric).
Reflects a Gaussian step off the boundaries to stay within [lower, upper].
Reflection preserves symmetry, so no Hastings correction is needed.
Fields
lower_bound: f64Lower bound (inclusive)
upper_bound: f64Upper bound (inclusive)